@@ -1,8 +1,8 @@
 #[inline(always)]
-pub(crate) fn distance_between<T>(_self: *const T, origin: *const T) -> usize {
+pub(crate) fn distance_between<T>(self_: *const T, origin: *const T) -> usize {
   let type_size: usize = core::mem::size_of::<T>();
-  assert!(0 < type_size && type_size <= core::usize::MAX);
-  let distance: usize = (_self as usize).wrapping_sub(origin as usize);
+  assert!(0 < type_size);
+  let distance: usize = (self_ as usize).wrapping_sub(origin as usize);
   unsafe { core::intrinsics::exact_div(distance, type_size) }
 }
 
